# coding: latin-1
import clr
import os
import tempfile
clr.AddReference('System.Windows.Forms')
clr.AddReferenceByPartialName('System.Drawing')
from System.Drawing import Image
from System.Windows.Forms import Panel, ImageLayout

CLIENT_CACHE_PATH = os.path.join(tempfile.gettempdir(), 'PLANTAProject')


def get_proportional_size(img_width, img_height, max_width, max_height):
    resizing_ratio_height = max_height / img_height
    resizing_ratio_width = max_width / img_width
    ratio = min(resizing_ratio_height, resizing_ratio_width)

    return ratio * img_width, ratio * img_height


def image_is_cached(rec_uuid):
    return os.path.isfile(os.path.join(CLIENT_CACHE_PATH, rec_uuid))


def get_scaled_image_panel(df):
    panel = Panel()
    rec_uuid = None
    for child_df in df.DataArea.ChildrenDF:
        if str(child_df.get_customizing_name()) == 'uuid':
            rec_uuid = child_df.GetValue[str]()
    if not rec_uuid or not image_is_cached(rec_uuid):
        return panel
    background_image = Image.FromFile(os.path.join(CLIENT_CACHE_PATH, rec_uuid))
    img_width = background_image.Size.Width
    img_height = background_image.Size.Height
    max_width = df.Customizing.Width
    max_height = df.Customizing.Height
    panel.Width, panel.Height = get_proportional_size(img_width, img_height, max_width, max_height)
    panel.BackgroundImage = background_image
    panel.BackgroundImageLayout = ImageLayout.Zoom

    return panel

