import os
import tempfile

import clr

clr.AddReference("System.Drawing")
clr.AddReference("System.IO")
clr.AddReference("System.Windows.Forms")
from System.Drawing import Image
from .file_handling import choose_file, FileHandler

IMAGE_FILTER = "Image Files(*.BMP;*.JPG;*.GIF;*.PNG)|*.BMP;*.JPG;*.GIF;*.PNG|All files (*.*)|*.*"

FILE_DIMENSIONS_TOO_LARGE = 0
NO_FILE_WAS_CHOSEN = 1
OTHER_ERROR = 2


class ImageHandler(FileHandler):

    def check_size(self, max_width, max_height):
        size = self.image.Size
        if (max_width and size.Width > max_width) or (max_height and size.Height > max_height):
            return False
        return True

    def exposed_get_cache_directory(self):
        return os.path.join(tempfile.gettempdir(), 'PLANTAProject')

    def exposed_exists_cache_directory(self, directory):
        # Ignore server argument, only here for backwards compatibility
        cache_path = self.exposed_get_cache_directory()

        if not os.path.exists(cache_path):
            return os.makedirs(cache_path)

        return True

    def exposed_choose_image_with_dialog(self, max_height=0, max_width=0):
        """Opens a file dialog with filter settings for image files.
        :returns The file path or an integer indicating a problem:
            0 - File dimensions are to large.
            1 - No file was chosen.
            2 - Wrong format."""
        self.file_path = choose_file(save_file=False, filter=IMAGE_FILTER)
        if self.file_path is None:
            return NO_FILE_WAS_CHOSEN
        try:
            self.image = Image.FromFile(self.file_path)
        except Exception as e:
            return OTHER_ERROR

        if max_height and max_width:
            if not self.check_size(max_width, max_height):
                return FILE_DIMENSIONS_TOO_LARGE

        return self.file_path

    def exposed_image_is_already_cached(self, cache_path, name):
        # Ignore server argument, only here for backwards compatibility
        cache_path = self.exposed_get_cache_directory()

        return os.path.isfile(os.path.join(cache_path, name))

    def exposed_clear_cache(self, directory):
        # Ignore server argument, only here for backwards compatibility
        cache_path = self.exposed_get_cache_directory()

        for file in os.listdir(cache_path):
            file_path = os.path.join(cache_path, file)
            self.exposed_delete_picture(file_path)

    def exposed_delete_picture(self, path):
        file_path = path

        try:
            os.unlink(file_path)
        except (IOError, WindowsError):
            # file is most likely already deleted for some reason 
            # or can not yet be deleted because it ist still blocked by a process
            pass

    def exposed_delete_pictures_except(self, blacklist_uuids, directory):
        # Ignore server argument, only here for backwards compatibility
        cache_path = self.exposed_get_cache_directory()

        files = [os.path.join(cache_path, file) for file in os.listdir(cache_path) if not file in blacklist_uuids]
        for file_path in files:
            self.exposed_delete_picture(file_path)
