import os

from csrpc import access
from ppms import ppms
from ppms.user_interface import file_transfer

__all__ = ['get_image_from_client_via_dialog', 'image_is_already_cached', 'get_cache_directory',
           'clear_image_cache', 'delete_pictures_by_uuid_blacklist']

FILE_DIMENSIONS_TOO_LARGE = 0
NO_FILE_WAS_CHOSEN = 1
OTHER_ERROR = 2
WRONG_FORMAT = 3

FILE_DIMENSIONS_TOO_LARGE_MESSAGE = '1208'
WRONG_FORMAT_MESSAGE = '1231'


def get_image_from_client_via_dialog(temp_file_path, max_height=0, max_width=0, show_errors=True):
    file_path = ''

    if access.service_is_available('image_handler'):
        image_handler = access.remote_service('image_handler')
        file_path = image_handler.choose_image_with_dialog(max_height, max_width)

    if type(file_path) == int and show_errors and file_path == 0:
        ppms.ui_message_id(FILE_DIMENSIONS_TOO_LARGE_MESSAGE)
        return None

    elif file_path == WRONG_FORMAT:
        ppms.ui_message_id(WRONG_FORMAT_MESSAGE)
        return None

    elif type(file_path) == int:
        return None

    temp_path = copy_remote_file_to_local_file(temp_file_path, file_path)

    return temp_path


def copy_remote_file_to_local_file(temp_file_path, remote_path):
    if remote_path is not None:
        try:
            _, file_name = os.path.split(remote_path)
            temp_path = os.path.join(temp_file_path, file_name)
            with open(temp_path, 'wb') as file:
                file_transfer.copy_remote_file_locally(remote_path=remote_path, local_file=file)
        except OSError:
            return None
        return temp_path


def image_is_already_cached(cache_path, name):
    if access.service_is_available('image_handler'):
        image_handler = access.remote_service('image_handler')
        image_handler.exists_cache_directory(cache_path)
        return image_handler.image_is_already_cached(cache_path, name)


def clear_image_cache(directory):
    if access.service_is_available('image_handler'):
        image_handler = access.remote_service('image_handler')
        image_handler.clear_cache(directory)


def delete_pictures_by_uuid_blacklist(blacklisted_uuids):
    if access.service_is_available('image_handler'):
        image_handler = access.remote_service('image_handler')
        try:
            path = image_handler.get_cache_directory()
        except:
            # Running DB 17+ with a older client
            path = r'Resources\Pictures'

        image_handler.delete_pictures_except(blacklisted_uuids, path)


def get_cache_directory():
    if access.service_is_available('image_handler'):
        image_handler = access.remote_service('image_handler')
        try:
            return image_handler.get_cache_directory()
        except:
            # Running DB 17+ with a older client
            return r'Resources\Pictures'

    return None
