# coding=utf-8
import io
import ntpath

from ppms import ppms
from ppms.user_interface import file_transfer
from csrpc import access

from . import image_handler


__all__ = ['send_images_to_client']


def send_images_to_client(uuids):
    if not access.service_is_available('file_handling') or not access.service_is_available('image_handler'):
        return False

    try:
        client_cache_path = image_handler.get_cache_directory()
    except:
        # Running DB 17+ with a older client
        client_cache_path = r'Resources\Pictures'

    for uuid in uuids:
        rec = ppms.search_record(98, [uuid], ['picture'])
        if not rec:
            continue

        h_link = rec.picture.get_hyperlink()
        name = str(uuid)
        if image_handler.image_is_already_cached(client_cache_path, name) or not h_link:
            continue

        file_handle = io.BytesIO(h_link.get_blob())
        try:
            # TODO check why this step doesn't work with a few images
            file_transfer.copy_local_file_remote(file_handle, ntpath.join(client_cache_path, name))
        except KeyError:
            pass

    return True
